@@ -6,6 +6,8 @@ from .abstract_drive import AbstractDrive
 from .combined_drive import CombinedDrive
 from .data import Data
 from .drive import Drive
+from .mumax3drive import Mumax3Drive
+from .oommfdrive import OOMMFDrive
 
 __version__ = pkg_resources.get_distribution(__name__).version
 
