@@ -23,7 +23,7 @@ class TestDrive:
 
         # Exception
         with pytest.raises(IOError):
-            drive = md.Drive(name=self.name, number=9, dirname=self.dirname)
+            drive = md.Drive(name=self.name, number=11, dirname=self.dirname)
 
     def test_repr(self):
         for drive in self.data:
@@ -46,9 +46,16 @@ class TestDrive:
             assert drive.info["drive_number"] == i
 
     def test_mif(self):
-        for drive in self.data:
-            assert isinstance(drive.mif, str)
-            assert "MIF" in drive.mif
+        for i in range(7):
+            drive = self.data[i]
+            assert isinstance(drive.calculator_script, str)
+            assert "MIF" in drive.calculator_script
+
+    def test_mx3(self):
+        for i in range(7, 10):
+            drive = self.data[i]
+            assert isinstance(drive.calculator_script, str)
+            assert "tableadd" in drive.calculator_script
 
     def test_m0(self):
         for drive in self.data:
@@ -122,3 +129,30 @@ class TestDrive:
                     )
                     for i in "xyz"
                 )
+
+    def test_hv(self):
+        for drive in self.data:
+            # some drives have only one z layer -> only xy plane
+            drive.hv(kdims=["x", "y"])
+        # time drives: 0, 1, 2, 4
+        plot = self.data[0].hv(kdims=["y", "z"], vdims=["y", "z"])
+        assert len(plot.kdims) == 2
+        assert "x" in plot.kdims
+        assert "t" in plot.kdims
+
+        plot = self.data[0].hv.scalar(kdims=["x", "t"])
+        assert len(plot.kdims) == 3
+        assert "comp" in plot.kdims
+        assert "y" in plot.kdims
+        assert "z" in plot.kdims
+
+        plot = self.data[0].hv.vector(kdims=["x", "t"], vdims=["x", None], cdim="z")
+        assert len(plot.kdims) == 2
+        assert "y" in plot.kdims
+        assert "z" in plot.kdims
+
+        plot = self.data[2].hv.contour(kdims=["x", "t"])
+        assert len(plot.kdims) == 3
+        assert "comp" in plot.kdims
+        assert "y" in plot.kdims
+        assert "z" in plot.kdims
